==> inca_tool-1.1.2-py3-none-any.whl: inca/tourism/postprocessing/visits_per_area.py <==
import geopandas as gpd
import os
import rasterio
import numpy as np
import pandas as pd
from rasterio import mask as msk

YEARS = [2000,2006,2012,2018,2021]
curdir = os.curdir

# assuming NUTS0 shapes did not changes much
# assuming all parts of country are also relevent to visits (canaries for spain?)
shapefile_path = r"C:\repos\inca_geopandas\NUTS_RG_03M_2016_3035.shp\NUTS_RG_03M_2016_3035.shp"
gdf = gpd.read_file(shapefile_path)

# select NUTS 0
gdf = gdf[gdf["LEVL_CODE"] == 0]

# get area
gdf["area"] = gdf.geometry.area

# USE - area per EU27
# -------------------
# read in USE
p2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\statistics"
f2r =  r"tourism_statistics_use_amountOvernightStays_{}.csv"

excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"

for year in YEARS:
    use2r = os.path.join(p2r.format(year),f2r.format(year))
    f2save = r"C:\repos\inca_geopandas\area_correction_stats\df_corr_use_{}.csv".format(year)
    f2save_Layout = r"C:\repos\inca_geopandas\area_correction_stats\use_km2_{}.csv".format(year)

    df = pd.read_csv(use2r)
    df = df.merge(gdf,left_on="NUTS_ID",right_on="NUTS_ID")
    df["areakm2"] = df["area"] / 1000000
    df["reporting"] = df["P6"] / df["areakm2"]
    df["foreign"] = df["P3_S14"] / df["areakm2"]

    df_final = df[["NUTS_ID","reporting","foreign"]]
    # df_final.to_csv(f2save)

    excel_use = pd.read_excel(excel2r.format(year,year),sheet_name="Use",skiprows=2, engine='openpyxl')
    excel_use = excel_use.merge(df_final,left_on="Unnamed: 1",right_on="NUTS_ID",how="left")
    excel_use["reporting"][excel_use["Unnamed: 1"] == "all regions"] = sum(df_final["reporting"])
    excel_use["foreign"][excel_use["Unnamed: 1"] == "all regions"] = sum(df_final["foreign"])

    # final formatting
    excel_use["Households final consumption"] = excel_use["reporting"]
    excel_use["Exports"] =  excel_use["foreign"]
    excel_use["total"] = excel_use["Households final consumption"] + excel_use["Exports"]
    excel_use = excel_use[["Unnamed: 1",
                           "total",
                           "Intermediate consumption by industries",
                           "Government final consumption",
                           "Households final consumption",
                           "Gross capital formation",
                           "Exports"]]
    excel_use = excel_use.rename(columns={"Unnamed: 1": "number of overnight stays/km2"})
    excel_use = excel_use.round(3)
    excel_use.to_csv(f2save_Layout,index=False,header=True)

# SUPPLY - area for each clc for each EU27
# ----------------------------------------
clc_path = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\TEMP\ecosystem_types_L1_{}.tif"

clc_lut = r"C:\repos\inca\src\inca\data\tourism_ecosystemTypeAttractivenessTable.csv"
clc_lut_df = pd.read_csv(clc_lut)

excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"


f2r =  r"tourism_statistics_supply_amountOvernightStays_{}.csv"
for year in YEARS:
    f2save_Layout = r"C:\repos\inca_geopandas\area_correction_stats\supply_km2_{}.csv".format(year)

    # SUT supply CSV
    supply2r = os.path.join(p2r.format(year),f2r.format(year))
    f2save = r"C:\repos\inca_geopandas\area_correction_stats\df_corr_supply_{}.csv".format(year)
    df_supply = pd.read_csv(supply2r)

    # SUT supply - for layout
    excel_supply = pd.read_excel(excel2r.format(year,year),sheet_name="Supply",skiprows=2, engine='openpyxl')
    excel_supply = excel_supply.rename(columns={"Unnamed: 1": "regions"})

    # col labels
    rename_dict = pd.read_csv(r"C:\repos\inca\src\inca\tourism\postprocessing\lu_dict.csv")
    lu_list = list(rename_dict["Label"])

    for col in lu_list:
        excel_supply[col][excel_supply["regions"] == "all regions"] = np.nansum(excel_supply[col])
    excel_supply["total"]  = excel_supply[lu_list].sum(axis=1)
    excel_supply = excel_supply.drop(columns=['Unnamed: 0'])

    # count pixels per category
    # check if the clc_counts csv was already generated
    path2check = r"C:\repos\inca_geopandas\area_correction_stats\area_clc_{}.csv".format(year)
    clc_counts_csv = os.path.exists(path2check)

    if not clc_counts_csv:

        # clc reclass
        raster_loaded = rasterio.open(clc_path.format(year,year))

        # loop over the polygons inside the gdf
        df_result_clc = pd.DataFrame(data=list(clc_lut_df["Code"]),columns=["clc_code"])
        clc_countit = 0
        for it_eu27,row_eu27 in df.iterrows():
            clc_countit = clc_countit + 1
            print("Checking poly  {}".format(row_eu27["NUTS_ID"]))
            # take zonal statistic
            rastermask,_ = msk.mask(dataset=raster_loaded,
                                              shapes=[row_eu27.geometry],
                                              crop=True,
                                              filled=False,
                                              indexes=1)


            # loop over the clc classes
            zonal_stat_row = []
            for it_clc,row_clc in clc_lut_df.iterrows():
                # append to zonal stat list
                code_clc = row_clc["Code"]
                label_clc = row_clc["Label"]
                count = len(rastermask[rastermask == code_clc])
                zonal_stat_row.append(count)

            df_result_clc[row_eu27["NUTS_ID"]] = zonal_stat_row

        df_result_clc.to_csv(path2check)
        result_clc = df_result_clc
    else:
        result_clc = pd.read_csv(path2check)

    rename_dict = dict(zip(rename_dict["Unnamed: 0"],rename_dict["Label"]))
    result_clc_trans = result_clc.transpose()
    result_clc_trans = result_clc_trans.rename(columns=rename_dict)

    # area sum for each country
    index_list = list(df_final["NUTS_ID"])
    sum_values = result_clc_trans.loc[index_list].sum()
    # Create a new DataFrame with the sum values
    sum_row = pd.DataFrame([sum_values], index=['all regions'], columns=result_clc_trans.columns)

    # Append the new row to the original DataFrame
    result_clc_trans = result_clc_trans.append(sum_row)
    result_clc_trans["total"] = result_clc_trans.sum(axis=1)

    lu_list.append("total")
    for ind,row in excel_supply.iterrows():
        country = row["regions"]
        for col in lu_list:
            area = result_clc_trans[col][result_clc_trans.index == country]
            excel_supply[col][ind] = excel_supply[col][ind] / area
        print(row)

    excel_supply = excel_supply.rename(columns={"regions": "number of overnight stays/km2"})
    excel_supply = excel_supply.round(3)

    excel_supply.to_csv(f2save_Layout,index=False,header=True)
    print("done")

==> inca_tool-1.9.6-py3-none-any.whl: inca/tourism/postprocessing/visits_per_area.py <==
import geopandas as gpd
import os
import rasterio
import numpy as np
import pandas as pd
from rasterio import mask as msk
RUN = 3
YEARS = [2000,2006,2012,2018,2021]
curdir = os.curdir

# assuming NUTS0 shapes did not changes much
# assuming all parts of country are also relevent to visits (canaries for spain?)
shapefile_path = r"C:\repos\inca_geopandas\NUTS_RG_03M_2016_3035.shp\NUTS_RG_03M_2016_3035.shp"
gdf = gpd.read_file(shapefile_path)

# select NUTS 0
gdf = gdf[gdf["LEVL_CODE"] == 0]

# get area
gdf["area"] = gdf.geometry.area

# USE - area per EU27
# -------------------
# read in USE
if RUN == 2:
    p2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\statistics"
else:
    p2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseriesRun3_{}\statistics"

f2r =  r"tourism_statistics_use_amountOvernightStays_{}.csv"
if RUN == 2:
    excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"
else:
    excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseriesRun3_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"

for year in YEARS:
    use2r = os.path.join(p2r.format(year),f2r.format(year))
    f2save = r"C:\repos\inca_geopandas\area_correction_stats\run{}\df_corr_use_{}.csv".format(RUN,year)
    f2save_Layout = r"C:\repos\inca_geopandas\area_correction_stats\run{}\use_km2_{}.csv".format(RUN,year)

    df = pd.read_csv(use2r)
    df = df.merge(gdf,left_on="NUTS_ID",right_on="NUTS_ID")
    df["areakm2"] = df["area"] / 1000000
    df["reporting"] = df["P6"] / df["areakm2"]
    df["foreign"] = df["P3_S14"] / df["areakm2"]

    df_final = df[["NUTS_ID","reporting","foreign"]]
    # df_final.to_csv(f2save)

    excel_use = pd.read_excel(excel2r.format(year,year),sheet_name="Use",skiprows=2, engine='openpyxl')
    excel_use = excel_use.merge(df_final,left_on="Unnamed: 1",right_on="NUTS_ID",how="left")
    excel_use["reporting"][excel_use["Unnamed: 1"] == "all regions"] = sum(df_final["reporting"])
    excel_use["foreign"][excel_use["Unnamed: 1"] == "all regions"] = sum(df_final["foreign"])

    # final formatting
    excel_use["Households final consumption"] = excel_use["reporting"]
    excel_use["Exports"] =  excel_use["foreign"]
    excel_use["total"] = excel_use["Households final consumption"] + excel_use["Exports"]
    excel_use = excel_use[["Unnamed: 1",
                           "total",
                           "Intermediate consumption by industries",
                           "Government final consumption",
                           "Households final consumption",
                           "Gross capital formation",
                           "Exports"]]
    excel_use = excel_use.rename(columns={"Unnamed: 1": "number of overnight stays/km2"})
    excel_use = excel_use.round(3)
    excel_use.to_csv(f2save_Layout,index=False,header=True)

# SUPPLY - area for each clc for each EU27
# ----------------------------------------
clc_path = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\TEMP\ecosystem_types_L1_{}.tif"

clc_lut = r"C:\repos\inca\src\inca\data\tourism_ecosystemTypeAttractivenessTable.csv"
clc_lut_df = pd.read_csv(clc_lut)

if RUN == 2:
    excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseries_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"
else:
    excel2r = r"C:\Dfold\inca2021series\output\tourism2021_fullseriesRun3_{}\SUTs\tourism_report_SUT_amountOvernightStays_{}.xlsx"


f2r =  r"tourism_statistics_supply_amountOvernightStays_{}.csv"
for year in YEARS:
    f2save_Layout = r"C:\repos\inca_geopandas\area_correction_stats\run{}\supply_km2_{}.csv".format(RUN,year)

    # SUT supply CSV
    supply2r = os.path.join(p2r.format(year),f2r.format(year))
    f2save = r"C:\repos\inca_geopandas\area_correction_stats\run{}\df_corr_supply_{}.csv".format(RUN,year)
    df_supply = pd.read_csv(supply2r)

    # SUT supply - for layout
    excel_supply = pd.read_excel(excel2r.format(year,year),sheet_name="Supply",skiprows=2, engine='openpyxl')
    excel_supply = excel_supply.rename(columns={"Unnamed: 1": "regions"})

    # col labels
    rename_dict = pd.read_csv(r"C:\repos\inca\src\inca\tourism\postprocessing\lu_dict.csv")
    lu_list = list(rename_dict["Label"])

    for col in lu_list:
        excel_supply[col][excel_supply["regions"] == "all regions"] = np.nansum(excel_supply[col])
    excel_supply["total"]  = excel_supply[lu_list].sum(axis=1)
    excel_supply = excel_supply.drop(columns=['Unnamed: 0'])

    # count pixels per category
    # check if the clc_counts csv was already generated
    path2check = r"C:\repos\inca_geopandas\area_correction_stats\run{}\area_clc_{}.csv".format(RUN,year)
    clc_counts_csv = os.path.exists(path2check)

    if not clc_counts_csv:

        # clc reclass
        raster_loaded = rasterio.open(clc_path.format(year,year))

        # loop over the polygons inside the gdf
        df_result_clc = pd.DataFrame(data=list(clc_lut_df["Code"]),columns=["clc_code"])
        clc_countit = 0
        for it_eu27,row_eu27 in df.iterrows():
            clc_countit = clc_countit + 1
            print("Checking poly  {}".format(row_eu27["NUTS_ID"]))
            # take zonal statistic
            rastermask,_ = msk.mask(dataset=raster_loaded,
                                              shapes=[row_eu27.geometry],
                                              crop=True,
                                              filled=False,
                                              indexes=1)


            # loop over the clc classes
            zonal_stat_row = []
            for it_clc,row_clc in clc_lut_df.iterrows():
                # append to zonal stat list
                code_clc = row_clc["Code"]
                label_clc = row_clc["Label"]
                count = len(rastermask[rastermask == code_clc])
                zonal_stat_row.append(count)

            df_result_clc[row_eu27["NUTS_ID"]] = zonal_stat_row

        df_result_clc.to_csv(path2check)
        result_clc = df_result_clc
    else:
        result_clc = pd.read_csv(path2check)

    rename_dict = dict(zip(rename_dict["Unnamed: 0"],rename_dict["Label"]))
    result_clc_trans = result_clc.transpose()
    result_clc_trans = result_clc_trans.rename(columns=rename_dict)

    # area sum for each country
    index_list = list(df_final["NUTS_ID"])
    sum_values = result_clc_trans.loc[index_list].sum()
    # Create a new DataFrame with the sum values
    sum_row = pd.DataFrame([sum_values], index=['all regions'], columns=result_clc_trans.columns)

    # Append the new row to the original DataFrame
    result_clc_trans = result_clc_trans.append(sum_row)
    result_clc_trans["total"] = result_clc_trans.sum(axis=1)

    lu_list.append("total")
    for ind,row in excel_supply.iterrows():
        country = row["regions"]
        for col in lu_list:
            area = result_clc_trans[col][result_clc_trans.index == country]
            excel_supply[col][ind] = excel_supply[col][ind] / area
        print(row)

    excel_supply = excel_supply.rename(columns={"regions": "number of overnight stays/km2"})
    excel_supply = excel_supply.round(3)

    excel_supply.to_csv(f2save_Layout,index=False,header=True)
    print("done")
